@@ -1,6 +1,6 @@
 /* Solve linear programming problems by either vertex/point enumeration
    or the primal simplex algorithm.
-   Copyright (C) 2001-2008 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -41,8 +41,22 @@ site: http://www.cs.unipr.it/ppl/ . */
 
 #ifdef PPL_HAVE_GETOPT_H
 # include <getopt.h>
+
+/* Try to accommodate non-GNU implementations of `getopt()'. */
+#if !defined(no_argument) && defined(NO_ARG)
+#define no_argument NO_ARG
 #endif
 
+#if !defined(required_argument) && defined(REQUIRED_ARG)
+#define required_argument REQUIRED_ARG
+#endif
+
+#if !defined(optional_argument) && defined(OPTIONAL_ARG)
+#define optional_argument OPTIONAL_ARG
+#endif
+
+#endif /* defined(PPL_HAVE_GETOPT_H) */
+
 #ifdef PPL_HAVE_UNISTD_H
 /* Include this for `getopt()': especially important if we do not have
    <getopt.h>. */
@@ -75,6 +89,15 @@ static const char* ppl_source_version = PPL_VERSION;
 # define ATTRIBUTE_UNUSED
 #endif
 
+#if PPL_HAVE_DECL_GETRUSAGE
+# define PPL_LPSOL_SUPPORTS_TIMINGS
+#endif
+
+#if defined(PPL_HAVE_SYS_RESOURCE_H) \
+  && (defined(SA_ONESHOT) || defined(SA_RESETHAND))
+# define PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
+#endif
+
 #ifdef PPL_HAVE_GETOPT_H
 static struct option long_options[] = {
   {"check",           optional_argument, 0, 'c'},
@@ -90,7 +113,9 @@ static struct option long_options[] = {
   {"pricing",         required_argument, 0, 'p'},
   {"enumerate",       no_argument,       0, 'e'},
   {"simplex",         no_argument,       0, 's'},
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
   {"timings",         no_argument,       0, 't'},
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
   {"verbosity",       required_argument, 0, 'v'},
   {"version",         no_argument,       0, 'V'},
   {0, 0, 0, 0}
@@ -121,9 +146,15 @@ static struct option long_options[] = {
   "                          0 --> steepest-edge using floating point\n" \
   "                          1 --> steepest-edge using exact arithmetic\n" \
   "                          2 --> textbook\n"                          \
-  "  -s, --simplex           use the simplex method\n"                  \
-  "  -t, --timings           prints timings to stderr\n"
+  "  -s, --simplex           use the simplex method\n"
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
 #define USAGE_STRING3                                                   \
+  "  -t, --timings           prints timings to stderr\n"
+#else /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+#define USAGE_STRING3                                                   \
+  ""
+#endif /* !defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+#define USAGE_STRING4                                                   \
   "  -v, --verbosity=LEVEL   sets verbosity level (from 0 to 4, default 3):\n" \
   "                          0 --> quiet: no output except for errors and\n" \
   "                                explicitly required notifications\n" \
@@ -132,19 +163,28 @@ static struct option long_options[] = {
   "                          3 --> state + optimal value + optimum location\n" \
   "                          4 --> lots of output\n"                    \
   "  -V, --version           prints version information to stdout\n"
+#ifndef PPL_HAVE_GETOPT_H
+#define USAGE_STRING5                                                   \
+  "\n"                                                                  \
+  "NOTE: this version does not support long options.\n"
+#else /* defined(PPL_HAVE_GETOPT_H) */
+#define USAGE_STRING5                                                   \
+  ""
+#endif /* !defined(PPL_HAVE_GETOPT_H) */
+#define USAGE_STRING6                                                   \
+  "\n"                                                                  \
+  "Report bugs to <ppl-devel@cs.unipr.it>.\n"
+
 
 #define OPTION_LETTERS "bc::eimnMC:R:ho:p:rstVv:"
 
 static const char* program_name = 0;
-
-static unsigned long max_seconds_of_cpu_time = 0;
 static unsigned long max_bytes_of_virtual_memory = 0;
 static const char* output_argument = 0;
 FILE* output_file = NULL;
 static int check_results = 0;
 static int use_simplex = 0;
 static int pricing_method = 0;
-static int print_timings = 0;
 static int verbosity = 3;
 static int maximize = 1;
 static int incremental = 0;
@@ -154,6 +194,14 @@ static int check_results_failed = 0;
 static double check_threshold = 0.0;
 static const double default_check_threshold = 0.000000001;
 
+#ifdef PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
+static unsigned long max_seconds_of_cpu_time = 0;
+#endif /* defined (PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME) */
+
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+static int print_timings = 0;
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
 static void
 my_exit(int status) {
   (void) ppl_finalize();
@@ -269,12 +317,12 @@ process_options(int argc, char* argv[]) {
       fputs(USAGE_STRING1, stdout);
       fputs(USAGE_STRING2, stdout);
       fputs(USAGE_STRING3, stdout);
-#ifndef PPL_HAVE_GETOPT_H
-      fputs("\nNOTE: this version does not support long options.\n");
-#endif
+      fputs(USAGE_STRING4, stdout);
       my_exit(0);
       break;
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
     case 'C':
       l = strtol(optarg, &endptr, 10);
       if (*endptr || l < 0)
@@ -283,6 +331,8 @@ process_options(int argc, char* argv[]) {
 	max_seconds_of_cpu_time = l;
       break;
 
+#endif /* defined (PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME) */
+
     case 'R':
       l = strtol(optarg, &endptr, 10);
       if (*endptr || l < 0)
@@ -311,10 +361,14 @@ process_options(int argc, char* argv[]) {
       simplex_required = 1;
       break;
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
     case 't':
       print_timings = 1;
       break;
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
     case 'v':
       l = strtol(optarg, &endptr, 10);
       if (*endptr || l < 0 || l > 4)
@@ -388,6 +442,8 @@ process_options(int argc, char* argv[]) {
     output_file = stdout;
 }
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
 /* To save the time when start_clock is called. */
 static struct timeval saved_ru_utime;
 
@@ -425,6 +481,10 @@ print_clock(FILE* f) {
   }
 }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
+#ifdef PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
+
 void
 set_alarm_on_cpu_time(unsigned seconds, void (*handler)(int)) {
   sigset_t mask;
@@ -440,7 +500,7 @@ set_alarm_on_cpu_time(unsigned seconds, void (*handler)(int)) {
 #elif defined(SA_RESETHAND)
   s.sa_flags = SA_RESETHAND;
 #else
-  #error "Either SA_ONESHOT or SA_RESETHAND must be defined."
+# error "Either SA_ONESHOT or SA_RESETHAND must be defined."
 #endif
 
   if (sigaction(SIGXCPU, &s, 0) != 0)
@@ -456,7 +516,10 @@ set_alarm_on_cpu_time(unsigned seconds, void (*handler)(int)) {
   }
 }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME) */
+
 #if PPL_HAVE_DECL_RLIMIT_AS
+
 void
 limit_virtual_memory(unsigned bytes) {
   struct rlimit t;
@@ -470,12 +533,17 @@ limit_virtual_memory(unsigned bytes) {
       fatal("setrlimit failed: %s", strerror(errno));
   }
 }
+
 #else
+
 void
 limit_virtual_memory(unsigned bytes ATTRIBUTE_UNUSED) {
 }
+
 #endif /* !PPL_HAVE_DECL_RLIMIT_AS */
 
+#ifdef PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
+
 static void
 my_timeout(int dummy ATTRIBUTE_UNUSED) {
   fprintf(stderr, "TIMEOUT\n");
@@ -484,6 +552,8 @@ my_timeout(int dummy ATTRIBUTE_UNUSED) {
   my_exit(0);
 }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME) */
+
 static mpz_t tmp_z;
 static mpq_t tmp1_q;
 static mpq_t tmp2_q;
@@ -706,6 +776,8 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
   /* Create the polyhedron (recycling the data structures of ppl_cs). */
   ppl_new_C_Polyhedron_recycle_Constraint_System(&ppl_ph, ppl_cs);
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings) {
     fprintf(stderr, "Time to create a PPL polyhedron: ");
     print_clock(stderr);
@@ -713,8 +785,12 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
     start_clock();
   }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   empty = ppl_Polyhedron_is_empty(ppl_ph);
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings) {
     fprintf(stderr, "Time to check for emptiness: ");
     print_clock(stderr);
@@ -722,6 +798,8 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
     start_clock();
   }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   if (empty) {
     if (verbosity >= 1)
       fprintf(output_file, "Unfeasible problem.\n");
@@ -743,6 +821,8 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
     ? !ppl_Polyhedron_bounds_from_above(ppl_ph, ppl_objective_le)
     : !ppl_Polyhedron_bounds_from_below(ppl_ph, ppl_objective_le);
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings) {
     fprintf(stderr, "Time to check for unboundedness: ");
     print_clock(stderr);
@@ -750,6 +830,8 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
     start_clock();
   }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   if (unbounded) {
     if (verbosity >= 1)
       fprintf(output_file, "Unbounded problem.\n");
@@ -770,6 +852,8 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
 
   ppl_delete_Polyhedron(ppl_ph);
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings) {
     fprintf(stderr, "Time to find the optimum: ");
     print_clock(stderr);
@@ -777,6 +861,8 @@ solve_with_generators(ppl_Constraint_System_t ppl_cs,
     start_clock();
   }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   if (!included)
     fatal("internal error");
 
@@ -860,6 +946,8 @@ solve_with_simplex(ppl_const_Constraint_System_t cs,
       status = ppl_MIP_Problem_solve(ppl_mip);
   }
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings) {
     fprintf(stderr, "Time to solve the problem: ");
     print_clock(stderr);
@@ -867,6 +955,8 @@ solve_with_simplex(ppl_const_Constraint_System_t cs,
     start_clock();
   }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   if ((no_optimization && !satisfiable)
       || (!no_optimization && status == PPL_MIP_PROBLEM_STATUS_UNFEASIBLE)) {
     if (verbosity >= 1)
@@ -923,9 +1013,13 @@ solve(char* file_name) {
   mpz_t den_lcm;
   int optimum_found;
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings)
     start_clock();
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   if (verbosity == 0) {
     /* FIXME: find a way to suppress output from lpx_read_mps. */
   }
@@ -935,6 +1029,8 @@ solve(char* file_name) {
   if (glpk_lp == NULL)
     fatal("cannot read MPS file `%s'", file_name);
 
+#ifdef PPL_LPSOL_SUPPORTS_TIMINGS
+
   if (print_timings) {
     fprintf(stderr, "Time to read the input file: ");
     print_clock(stderr);
@@ -942,6 +1038,8 @@ solve(char* file_name) {
     start_clock();
   }
 
+#endif /* defined(PPL_LPSOL_SUPPORTS_TIMINGS) */
+
   glpk_lp_problem_kind = lpx_get_class(glpk_lp);
   if (glpk_lp_problem_kind == LPX_MIP && !no_mip && !use_simplex)
      fatal("the enumeration solving method can not handle MIP problems");
@@ -1179,11 +1277,21 @@ ppl_set_GMP_memory_allocation_functions(void) {
 }
 #endif
 
-#if defined(NDEBUG) && \
-  !(defined(PPL_GLPK_HAS_GLP_TERM_OUT) && defined(GLP_OFF))     \
-  && (defined(PPL_GLPK_HAS_GLP_TERM_HOOK) \
-      || defined(PPL_GLPK_HAS__GLP_LIB_PRINT_HOOK) \
-      || defined(PPL_GLPK_HAS_LIB_SET_PRINT_HOOK))
+#if defined(NDEBUG)
+
+#if !(defined(PPL_GLPK_HAS_GLP_TERM_OUT) && defined(GLP_OFF))
+
+#if defined(PPL_GLPK_HAS_GLP_TERM_HOOK) \
+  || defined(PPL_GLPK_HAS__GLP_LIB_PRINT_HOOK)
+
+static int
+glpk_message_interceptor(void* info, const char* msg) {
+  (void) info;
+  (void) msg;
+  return 1;
+}
+
+#elif defined(PPL_GLPK_HAS_LIB_SET_PRINT_HOOK)
 
 static int
 glpk_message_interceptor(void* info, char* msg) {
@@ -1192,12 +1300,18 @@ glpk_message_interceptor(void* info, char* msg) {
   return 1;
 }
 
-#endif
+#endif /* !(defined(PPL_GLPK_HAS_GLP_TERM_HOOK)
+            || defined(PPL_GLPK_HAS__GLP_LIB_PRINT_HOOK))
+          && defined(PPL_GLPK_HAS_LIB_SET_PRINT_HOOK) */
+
+#endif /* !(defined(PPL_GLPK_HAS_GLP_TERM_OUT) && defined(GLP_OFF)) */
+
+#endif /* defined(NDEBUG) */
 
 int
 main(int argc, char* argv[]) {
 #if defined(PPL_GLPK_HAS__GLP_LIB_PRINT_HOOK)
-  extern void _glp_lib_print_hook(int (*func)(void *info, char *buf),
+  extern void _glp_lib_print_hook(int (*func)(void *info, const char *buf),
 				  void *info);
 #endif
   program_name = argv[0];
@@ -1242,9 +1356,13 @@ main(int argc, char* argv[]) {
   mpq_init(tmp2_q);
   ppl_new_Coefficient(&ppl_coeff);
 
+#ifdef PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME
+
   if (max_seconds_of_cpu_time > 0)
     set_alarm_on_cpu_time(max_seconds_of_cpu_time, my_timeout);
 
+#endif /* defined (PPL_LPSOL_SUPPORTS_LIMIT_ON_CPU_TIME) */
+
   if (max_bytes_of_virtual_memory > 0)
     limit_virtual_memory(max_bytes_of_virtual_memory);
 
