@@ -1,11 +1,11 @@
 /* Test Grid::remove_space_dimensions().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -24,6 +24,8 @@ site: http://www.cs.unipr.it/ppl/ . */
 
 namespace {
 
+// Testing remove_space_dimensions
+
 // Simple grid.
 bool
 test01() {
@@ -31,9 +33,9 @@ test01() {
   Variable B(1);
 
   Grid gr(2);
-  gr.add_congruence(A - B == 0);
+  gr.add_constraint(A - B == 0);
   gr.add_congruence(A %= 0);
-  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+  print_congruences(gr, "*** gr ***");
 
   Variables_Set vars;
   vars.insert(B);
@@ -56,7 +58,7 @@ test02() {
   Variable B(1);
 
   Grid gr(4, EMPTY);
-  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+  print_congruences(gr, "*** gr ***");
 
   Variables_Set vars;
   vars.insert(B);
@@ -73,7 +75,6 @@ test02() {
 }
 
 // Universe grid.
-
 bool
 test03() {
   Variable C(2);
@@ -102,13 +103,13 @@ test04() {
   Variable A(0);
   Variable B(1);
 
-  Grid_Generator_System gs;
-  gs.insert(grid_point(0*A));
-  gs.insert(grid_point(2*A));
-  gs.insert(grid_point(3*B));
+  Grid_Generator_System ggs;
+  ggs.insert(grid_point(0*A));
+  ggs.insert(grid_point(2*A));
+  ggs.insert(grid_point(3*B));
 
-  Grid gr(gs);
-  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+  Grid gr(ggs);
+  print_generators(gr, "*** gr ***");
 
   Variables_Set vars;
   vars.insert(B);
@@ -145,17 +146,17 @@ test05() {
   cgs.insert((B - E %= 0) / 2);
 
   Grid gr(cgs);
-  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+  print_congruences(gr, "*** gr ***");
 
   gr.remove_space_dimensions(vars);
 
-  Grid_Generator_System known_gs;
-  known_gs.insert(grid_point());
-  known_gs.insert(grid_line(2*A - B));
-  known_gs.insert(grid_point(3*B, 2));
-  known_gs.insert(grid_line(C));
+  Grid_Generator_System known_ggs;
+  known_ggs.insert(grid_point());
+  known_ggs.insert(grid_line(2*A - B));
+  known_ggs.insert(grid_point(3*B, 2));
+  known_ggs.insert(grid_line(C));
 
-  Grid known_gr(known_gs);
+  Grid known_gr(known_ggs);
 
   bool ok = (gr == known_gr);
 
@@ -172,8 +173,9 @@ test06() {
   Variable C(2);
 
   Grid gr(3);
-  gr.add_congruence(A - B == 0);
+  gr.add_constraint(A - B == 0);
   gr.add_congruence(A %= 0);
+  print_congruences(gr, "*** gr ***");
 
   Variables_Set vars;
   vars.insert(A);
@@ -186,7 +188,7 @@ test06() {
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr, "*** gr ***");
+  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
 
   return ok;
 }
@@ -199,11 +201,11 @@ test07() {
   Variable C(2);
 
   Grid gr(3, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator_and_minimize(grid_point(B));
-  gr.add_generator(grid_line(C));
-  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator_and_minimize(grid_point(B));
+  gr.add_grid_generator(grid_line(C));
+  print_generators(gr, "*** gr ***");
 
   Variables_Set vars;
   vars.insert(B);
@@ -215,13 +217,12 @@ test07() {
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr, "*** gr ***");
+  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
 
   return ok;
 }
 
-// Empty variable set.
-
+// The resulting grid contains a line that is all zeros.
 bool
 test08() {
   Variable A(0);
@@ -229,10 +230,40 @@ test08() {
   Variable C(2);
 
   Grid gr(3, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator_and_minimize(grid_point(B));
-  gr.add_generator(grid_line(C));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator(parameter(B));
+  gr.add_grid_generator(grid_line(C));
+  print_generators(gr, "*** gr ***");
+
+  Variables_Set vars;
+  vars.insert(C);
+
+  gr.remove_space_dimensions(vars);
+
+  Grid known_gr(2);
+  known_gr.add_congruence(A %= 0);
+  known_gr.add_congruence(B %= 0);
+
+  bool ok = (gr == known_gr);
+
+  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+
+  return ok;
+}
+
+// Empty variable set.
+bool
+test09() {
+  Variable A(0);
+  Variable B(1);
+  Variable C(2);
+
+  Grid gr(3, EMPTY);
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator_and_minimize(grid_point(B));
+  gr.add_grid_generator(grid_line(C));
   print_generators(gr, "*** gr ***");
 
   Variables_Set vars;
@@ -248,10 +279,39 @@ test08() {
   return ok;
 }
 
-// Space dimension exception.
-
+// Zero dimension universe resulting grid.
 bool
-test09() {
+test10() {
+  Variable A(0);
+  Variable B(1);
+  Variable C(2);
+
+  Grid gr(3, EMPTY);
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator_and_minimize(grid_point(B));
+  gr.add_grid_generator(grid_line(C));
+  print_generators(gr, "*** gr ***");
+
+  Variables_Set vars;
+  vars.insert(A);
+  vars.insert(B);
+  vars.insert(C);
+
+  gr.remove_space_dimensions(vars);
+
+  Grid known_gr(0);
+
+  bool ok = (gr == known_gr);
+
+  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
+
+  return ok;
+}
+
+// Space dimension exception.
+bool
+test11() {
   Variable B(1);
 
   Grid gr(1, EMPTY);
@@ -265,200 +325,11 @@ test09() {
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
-}
-
-// Zero dimension universe resulting grid.
-bool
-test10() {
-  Variable A(0);
-  Variable B(1);
-  Variable C(2);
-
-  Grid gr(3, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator_and_minimize(grid_point(B));
-  gr.add_generator(grid_line(C));
-  print_generators(gr, "*** gr ***");
-
-  Variables_Set vars;
-  vars.insert(A);
-  vars.insert(B);
-  vars.insert(C);
-
-  gr.remove_space_dimensions(vars);
-
-  Grid known_gr(0);
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_space_dimensions(vars) ***");
-
-  return ok;
-}
-
-// From congruences.
-bool
-test11() {
-  Variable A(0);
-  Variable B(1);
-  Variable C(2);
-
-  Congruence_System cgs;
-  cgs.insert((A + 2*C %= 0) / 3);
-
-  Grid gr(cgs);
-  print_generators(gr, "*** gr ***");
-
-  gr.remove_higher_space_dimensions(2);
-
-  Grid_Generator_System known_gs;
-  known_gs.insert(grid_point(0*B));
-  known_gs.insert(grid_line(A));
-  known_gs.insert(grid_line(B));
-
-  Grid known_gr(known_gs);
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_higher_space_dimensions(2) ***");
-
-  return ok;
-}
-
-// Empty grid.
-bool
-test12() {
-  Grid gr(2, EMPTY);
-  print_generators(gr, "*** gr ***");
-
-  gr.remove_higher_space_dimensions(1);
-
-  Grid known_gr(1, EMPTY);
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_higher_space_dimensions(1) ***");
-
-  return ok;
-}
-
-// Universe grid.
-bool
-test13() {
-  Grid gr(7);
-
-  gr.remove_higher_space_dimensions(3);
-
-  Grid known_gr(3);
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_higher_space_dimensions(3) ***");
-
-  return ok;
-}
-
-// From generators.
-bool
-test14() {
-  Variable A(0);
-  Variable B(1);
-
-  Grid_Generator_System gs;
-  gs.insert(grid_point(0*A));
-  gs.insert(grid_point(2*A));
-  gs.insert(grid_point(3*B));
-
-  Grid gr(gs);
-  print_generators(gr, "*** gr ***");
-
-  gr.remove_higher_space_dimensions(1);
-
-  Congruence_System known_cgs;
-  known_cgs.insert((A %= 0) / 2);
-
-  Grid known_gr(known_cgs);
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_higher_space_dimensions(1) ***");
-
-  return ok;
-}
-
-// Resulting grid the same.
-
-bool
-test15() {
-  Variable A(0);
-  Variable B(1);
-  Variable C(2);
-
-  Grid gr(3, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator_and_minimize(grid_point(B));
-  gr.add_generator(grid_line(C));
-  print_generators(gr, "*** gr ***");
-
-  Grid known_gr = gr;
-
-  gr.remove_higher_space_dimensions(gr.space_dimension());
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_higher_space_dimensions() ***");
-
-  return ok;
-}
-
-// Space dimension exception.
-bool
-test16() {
-  Grid gr(1, EMPTY);
-  print_generators(gr, "*** gr ***");
-
-  try {
-    gr.remove_higher_space_dimensions(6);
-  }
-  catch (const std::invalid_argument& e) {
-    nout << "invalid_argument: " << e.what() << endl;
-  }
-  catch (...) {
-    return false;
-  }
-  return true;
-}
-
-// Zero dimension universe resulting grid.
-bool
-test17() {
-  Variable A(0);
-  Variable B(1);
-  Variable C(2);
-
-  Grid gr(3, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator_and_minimize(grid_point(B));
-  gr.add_generator(grid_line(C));
-  print_generators(gr, "*** gr ***");
-
-  gr.remove_higher_space_dimensions(0);
-
-  Grid known_gr(0);
-
-  bool ok = (gr == known_gr);
-
-  print_congruences(gr, "*** gr.remove_higher_space_dimensions(0) ***");
-
-  return ok;
+  return false;
 }
 
 } // namespace
@@ -475,10 +346,4 @@ BEGIN_MAIN
   DO_TEST(test09);
   DO_TEST(test10);
   DO_TEST(test11);
-  DO_TEST(test12);
-  DO_TEST(test13);
-  DO_TEST(test14);
-  DO_TEST(test15);
-  DO_TEST(test16);
-  DO_TEST(test17);
 END_MAIN
