@@ -1,11 +1,11 @@
-/* Test Grid::widening_assign().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+/* Test Grid::congruence_widening_assign().
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -40,12 +40,11 @@ test01() {
 
   Grid known_gr = gr2;
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -56,8 +55,8 @@ test02() {
   Variable A(0);
 
   Grid gr1(1);
-  gr1.add_congruence(A == 0);
-  gr1.add_congruence(A == 1);
+  gr1.add_constraint(A == 0);
+  gr1.add_constraint(A == 1);
 
   print_congruences(gr1, "*** gr1 ***");
 
@@ -68,12 +67,11 @@ test02() {
 
   Grid known_gr = gr2;
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -84,8 +82,8 @@ test03() {
   Variable A(0);
 
   Grid gr1(1);
-  gr1.add_congruence(A == 0);
-  gr1.add_congruence(A == 1);
+  gr1.add_constraint(A == 0);
+  gr1.add_constraint(A == 1);
 
   print_congruences(gr1, "*** gr1 ***");
 
@@ -95,12 +93,11 @@ test03() {
 
   Grid known_gr = gr2;
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -112,25 +109,24 @@ test04() {
   Variable B(1);
 
   Grid gr1(2);
-  gr1.add_congruence(A == 0);
-  gr1.add_congruence(B == 1);
+  gr1.add_constraint(A == 0);
+  gr1.add_constraint(B == 1);
 
   print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(2);
-  gr2.add_congruence(A == 0);
+  gr2.add_constraint(A == 0);
   gr2.add_congruence(B %= 1);
 
   print_congruences(gr2, "*** gr2 ***");
 
   Grid known_gr = gr2;
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -157,12 +153,11 @@ test05() {
 
   Grid known_gr = gr2;
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -188,7 +183,7 @@ test06() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(3);
   known_gr.add_congruence((B %= 0) / 2);
@@ -196,8 +191,7 @@ test06() {
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -223,15 +217,14 @@ test07() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(3);
   known_gr.add_congruence((B %= 0) / 2);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -246,20 +239,18 @@ test08() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(5);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
 
 // Widening when increasing to universe.
-
 bool
 test09() {
   Variable A(0);
@@ -273,14 +264,13 @@ test09() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(4);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -306,14 +296,13 @@ test10() {
 
   Grid known_gr = gr2;
 
-  gr2.widening_assign(gr1, &tokens);
+  gr2.congruence_widening_assign(gr1, &tokens);
 
   bool ok = ((gr2 == known_gr) && (tokens == 3));
 
   nout << "*** `tokens' should be 3 ***" << tokens << endl;
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1, &tokens) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1, &tokens) ***");
 
   return ok;
 }
@@ -329,14 +318,13 @@ test11() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(0);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -351,23 +339,22 @@ test12() {
   gr1.add_congruence(5*A + B %= 0);
   gr1.add_congruence(22*A %= 0);
 
-  print_congruences(gr1, "gr1: ");
+  print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(2);
   gr2.add_congruence(5*A + B %= 0);
   gr2.add_congruence(44*A %= 0);
 
-  print_congruences(gr2, "gr2: ");
+  print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(2);
   known_gr.add_congruence(5*A + B %= 0);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -382,23 +369,22 @@ test13() {
   gr1.add_congruence(9*A + B %= 0);
   gr1.add_congruence(22*A %= 0);
 
-  print_congruences(gr1, "gr1: ");
+  print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(2);
   gr2.add_congruence(9*A + B %= 0);
   gr2.add_congruence(44*A %= 0);
 
-  print_congruences(gr2, "gr2: ");
+  print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(2);
   known_gr.add_congruence(9*A + B %= 0);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -421,15 +407,14 @@ test14() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(2);
   known_gr.add_congruence((A + B %= 0) / 2);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -452,15 +437,14 @@ test15() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(2);
   known_gr.add_congruence((A + B %= 0) / 2);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -483,15 +467,14 @@ test16() {
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(2);
   known_gr.add_congruence((A - B == 0) / 3);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -504,27 +487,26 @@ test17() {
   Variable C(2);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point(C, 3));
-  gr1.add_generator(grid_point(C + A - 2*B, 3));
+  gr1.add_grid_generator(grid_point(C, 3));
+  gr1.add_grid_generator(grid_point(C + A - 2*B, 3));
 
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point(C, 3));
-  gr2.add_generator(grid_point(2*C + A - 2*B, 6));
+  gr2.add_grid_generator(grid_point(C, 3));
+  gr2.add_grid_generator(grid_point(2*C + A - 2*B, 6));
 
   print_generators(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(3, EMPTY);
-  known_gr.add_generator(grid_point(C, 3));
-  known_gr.add_generator(grid_line(A - 2*B));
+  known_gr.add_grid_generator(grid_point(C, 3));
+  known_gr.add_grid_generator(grid_line(A - 2*B));
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
@@ -538,27 +520,27 @@ test18() {
   Variable C(2);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point(C, 3));
-  gr1.add_generator(grid_point(C + A - 2*B, 3));
+  gr1.add_grid_generator(grid_point(C, 3));
+  gr1.add_grid_generator(grid_point(C + A - 2*B, 3));
 
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(4, EMPTY);
-  gr2.add_generator(grid_point(C, 3));
-  gr2.add_generator(grid_point(2*C + A - 2*B, 6));
+  gr2.add_grid_generator(grid_point(C, 3));
+  gr2.add_grid_generator(grid_point(2*C + A - 2*B, 6));
 
   print_generators(gr2, "*** gr2 ***");
 
   try {
-    gr2.widening_assign(gr1);
+    gr2.congruence_widening_assign(gr1);
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Minimizing the first congruence system finds the empty grid.
@@ -567,25 +549,24 @@ test19() {
   Variable A(0);
 
   Grid gr1(3);
-  gr1.add_congruence(A == 0);
-  gr1.add_congruence(A == 1);
+  gr1.add_constraint(A == 0);
+  gr1.add_constraint(A == 1);
 
   print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(3);
-  gr2.add_congruence(A == 0);
-  gr2.add_congruence(A == 1);
+  gr2.add_constraint(A == 0);
+  gr2.add_constraint(A == 1);
 
   print_congruences(gr2, "*** gr2 ***");
 
-  gr2.widening_assign(gr1);
+  gr2.congruence_widening_assign(gr1);
 
   Grid known_gr(3, EMPTY);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2,
-        "*** gr2.widening_assign(gr1) ***");
+  print_congruences(gr2, "*** gr2.congruence_widening_assign(gr1) ***");
 
   return ok;
 }
