@@ -1,11 +1,11 @@
 /* An example of iteration to a post-fixpoint.
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -98,9 +98,10 @@ fix_point(C_Polyhedron& start, C_Polyhedron& induct, C_Polyhedron& finish,
 
     print_constraints(current, "*** after remove_space_dimensions ***");
 
-    current.poly_hull_assign_and_minimize(previous);
+    current.upper_bound_assign(previous);
+    (void) current.is_empty();
 
-    print_constraints(current, "*** after poly_hull_assign_and_minimize***");
+    print_constraints(current, "*** after upper_bound_assign ***");
 
   } while (current != previous);
   finish = current;
@@ -108,10 +109,8 @@ fix_point(C_Polyhedron& start, C_Polyhedron& induct, C_Polyhedron& finish,
 
 } // namespace
 
-int
-main() TRY {
-  set_handlers();
-
+bool
+test01() {
   C_Polyhedron start;
   C_Polyhedron induct;
   C_Polyhedron expect;
@@ -122,8 +121,11 @@ main() TRY {
   C_Polyhedron final;
   fix_point(start, induct, final, recursive_offset, arity, num_vars);
 
-    print_constraints(expect, "*** expected ***");
+  print_constraints(expect, "*** expected ***");
 
-  return final == expect ? 0 : 1;
+  return final == expect ? true : false;
 }
-CATCH
+
+BEGIN_MAIN
+  DO_TEST(test01);
+END_MAIN
