@@ -1,5 +1,5 @@
 /* Implementation of utility functions used in test programs.
-   Copyright (C) 2001-2008 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -43,6 +43,7 @@ uncaught_exception_handler() {
   exit(1);
 }
 
+#ifdef HAVE_SIGINFO_T
 void
 fpe_handler(int sig, siginfo_t* sip, void*) {
   if (sig != SIGFPE) {
@@ -112,6 +113,7 @@ fpe_handler(int sig, siginfo_t* sip, void*) {
   }
   exit(1);
 }
+#endif // defined(HAVE_SIGINFO_T)
 
 } // namespace
 
@@ -121,6 +123,7 @@ namespace Test {
 
 void
 set_handlers() {
+#ifdef HAVE_SIGINFO_T
   struct sigaction action;
   action.sa_sigaction = fpe_handler;
   sigemptyset(&action.sa_mask);
@@ -130,6 +133,7 @@ set_handlers() {
 	      << std::endl;
     abort();
   }
+#endif // defined(HAVE_SIGINFO_T)
 
   std::set_unexpected(unexpected_exception_handler);
   std::set_terminate(uncaught_exception_handler);
